import { useMemo, lazy } from 'react';
/**
 * Async component loading for use with Dashboard.
 *
 * Should be used with component wrapped in `React.Suspense`
 *
 * @example
 * ```
 * const AsyncHeader = () => {
 *  const Header = useAsyncComponent('Header');
 *
 *  return <Header>Hello world!</Header>
 * }
 *
 * ...
 *
 * <React.Suspense fallback={<Loader active />}>
 *   <AsyncHeader />
 * </React.Suspense>
 * ```
 */
export var useWidget = function (type) {
    return useMemo(function () {
        switch (type) {
            case 'SessionList':
                return lazy(function () {
                    return import('./SessionList').then(function (module) { return ({
                        default: module.SessionList,
                    }); });
                });
            case 'Statistic':
                return lazy(function () {
                    return import('./Statistic').then(function (module) { return ({
                        default: module.Statistic,
                    }); });
                });
            case 'Welcome':
                return lazy(function () {
                    return import('./welcome').then(function (module) { return ({ default: module.Welcome }); });
                });
            case 'TopContributors':
                return lazy(function () {
                    return import('./TopContributors').then(function (module) { return ({
                        default: module.TopContributors,
                    }); });
                });
            case 'Demo':
                return lazy(function () {
                    return import('./Demo').then(function (module) { return ({ default: module.Demo }); });
                });
            default:
                if (type) {
                    console.warn("Async component '" + type + "' not supported");
                }
                return lazy(function () { return import('../../elements/Flex/Box'); });
        }
    }, [type]);
};
